var searchData=
[
  ['c',['C',['../namespaceplplot.html#aea2545117331b1b23d6084803c704478',1,'plplot']]],
  ['c1',['c1',['../structPLControlPt.html#a1dba38063cf7e0715477cd6547f289ad',1,'PLControlPt']]],
  ['c2',['c2',['../structPLControlPt.html#a5807db3f5421dea3724d9670532bc19b',1,'PLControlPt']]],
  ['c3',['c3',['../structPLControlPt.html#a600b3cab85525d717e054baa8d731038',1,'PLControlPt']]],
  ['c_5fplcgrid',['c_PLcGrid',['../namespaceplplot.html#ae0952584f6d3334a3314373e9de68ab2',1,'plplot']]],
  ['c_5fplcgrid2',['c_PLcGrid2',['../namespaceplplot.html#ac0a3be6d22835e74179254e1635499bc',1,'plplot']]],
  ['cached',['cached',['../structDIR.html#a3a41d5f8c72e7d7100c0259f375d2993',1,'DIR']]],
  ['cairo_5foptions',['cairo_options',['../cairo_8c.html#a23dccfc537aefb11001af1e2033a7fa2',1,'cairo.c']]],
  ['cairocontext',['cairoContext',['../structPLCairo.html#af332c5800cda1a2db4dffef2345ae4a3',1,'PLCairo']]],
  ['cairocontext_5fraster',['cairoContext_raster',['../structPLCairo.html#ab6d4231aec898f4db9e7a67cbe42190c',1,'PLCairo']]],
  ['cairosurface',['cairoSurface',['../structPLCairo.html#a2371f1072bb15661795e9cf12fc4a42b',1,'PLCairo']]],
  ['cairosurface_5fraster',['cairoSurface_raster',['../structPLCairo.html#a27e5eb8bc95d4b7b5ec150748090c7d3',1,'PLCairo']]],
  ['canvasxsize',['canvasXSize',['../structSVG.html#af90fe5aa3fc997b32d55a20d20564742',1,'SVG']]],
  ['canvasysize',['canvasYSize',['../structSVG.html#a7aeedfc913de101471b1415195db19b9',1,'SVG']]],
  ['caspfactor',['caspfactor',['../structPLStream.html#ae6456f977651a5e70b53ec8b18669ee1',1,'PLStream']]],
  ['cast',['cast',['../structswig__type__info.html#ae535f16234db99893f07880cb94a848e',1,'swig_type_info']]],
  ['cast_5finitial',['cast_initial',['../structswig__module__info.html#a14e4f7b0c9e0ff10543475c269b83507',1,'swig_module_info']]],
  ['ccontrol',['ccontrol',['../structQSASConfigStruct.html#ac4ca67a456f6701b82156c52f0bf4441',1,'QSASConfigStruct']]],
  ['cfont',['cfont',['../structPLStream.html#a8645356b1890060642f0b2076b62c82f',1,'PLStream']]],
  ['child',['child',['../plserver_8c.html#a4d7e3f55d165c752486b8f10d9af6b56',1,'plserver.c']]],
  ['child_5fpid',['child_pid',['../structTkDev.html#a831c88766d8d22f285c17b08667c65f7',1,'TkDev']]],
  ['chrdef',['chrdef',['../structPLStream.html#a8d7ce7ca2443356c163982d97066b112',1,'PLStream']]],
  ['chrht',['chrht',['../structPLStream.html#a6c335d8cba04eec1e566fe8cb570f5a6',1,'PLStream']]],
  ['circles',['circles',['../structdelaunay.html#a90b27c75e57441ff1c05d982decc2add',1,'delaunay']]],
  ['client',['client',['../structPLRDev.html#a287bd428530f97204f6f373c69b990f6',1,'PLRDev']]],
  ['client_5fdata',['client_data',['../structplplot_1_1__N1.html#ac736963f2331c6369230241983e63f29',1,'plplot::_N1::client_data()'],['../structPLOptionTable.html#abf2b587b8340cfa0b00349b02dd62aa7',1,'PLOptionTable::client_data()']]],
  ['client_5fhost',['client_host',['../plserver_8c.html#aafade1970b63a62fc7e25cc58d4c7927',1,'plserver.c']]],
  ['client_5fname',['client_name',['../plserver_8c.html#ac31d6d1fcf75f9fd1e0c65bbab284d49',1,'plserver.c']]],
  ['client_5fport',['client_port',['../plserver_8c.html#ae182f91946d7b87506442ed3f37f2cfb',1,'plserver.c']]],
  ['clientdata',['clientData',['../structCommand.html#a20ac86c445651c87898cf7802e2324a2',1,'Command::clientData()'],['../structswig__type__info.html#a2e1f9087e639dd7c8c131fbc6e399194',1,'swig_type_info::clientdata()'],['../structswig__module__info.html#a39999692b76f191b66a5ce746681dc84',1,'swig_module_info::clientdata()']]],
  ['clpxma',['clpxma',['../structPLStream.html#ac6e99ff104e7775673bf6cc3a520151a',1,'PLStream']]],
  ['clpxmi',['clpxmi',['../structPLStream.html#ac1cb48c958c8a95ecb08a84106843953',1,'PLStream']]],
  ['clpyma',['clpyma',['../structPLStream.html#a54d54311cae100f303fe6c1f74181639',1,'PLStream']]],
  ['clpymi',['clpymi',['../structPLStream.html#a1579b4aa16d0d6656c60b6140d71bc29',1,'PLStream']]],
  ['cls_5fstatic',['cls_static',['../structswig__lua__class.html#a41b17587e0b26e2112200adfffb22730',1,'swig_lua_class']]],
  ['cmap0',['cmap0',['../structTkwDisplay.html#a73cfdca12037d134b116c27b086d453b',1,'TkwDisplay::cmap0()'],['../structPLStream.html#a2cfea596db61b202941a2493c44fe609',1,'PLStream::cmap0()'],['../structXwDisplay.html#a730003c70ffced20691703ba8a0c253b',1,'XwDisplay::cmap0()']]],
  ['cmap1',['cmap1',['../structTkwDisplay.html#ae22e700c879ed55e39fe9d4d3719f3b1',1,'TkwDisplay::cmap1()'],['../structPLStream.html#abfb11a827bc7132ff5d27adde749912a',1,'PLStream::cmap1()'],['../structXwDisplay.html#add7434ff5062a982e1bb210d25422610',1,'XwDisplay::cmap1()']]],
  ['cmap1_5fmax',['cmap1_max',['../structPLStream.html#acfaba83b23c3137edac8768b9cc4dc59',1,'PLStream']]],
  ['cmap1_5fmin',['cmap1_min',['../structPLStream.html#a38aa4072d8dd697e1220bed77b4748e8',1,'PLStream']]],
  ['cmap1cp',['cmap1cp',['../structPLStream.html#ad2c579c767880b5fd0a80be14c039411',1,'PLStream']]],
  ['cmap1cp_5fis_5frgb',['cmap1cp_is_rgb',['../structPLStream.html#a56fbb6d1b8bb0d54d524cd9af4f694ca',1,'PLStream']]],
  ['cmd',['cmd',['../structplplot_1_1__N11.html#ada7f7976ca742a2e6306d7d850d2b286',1,'plplot::_N11::cmd()'],['../structtclMatrixXtnsnDescr.html#a4500e93e11a08db69584e9263a6f528c',1,'tclMatrixXtnsnDescr::cmd()'],['../structPLBufferingCB.html#ab3e77a6ccb3f11035c134cda510faabb',1,'PLBufferingCB::cmd()']]],
  ['cmdbuf',['cmdbuf',['../structTkDev.html#a94c2333d62e0dc364760cbc8878084bd',1,'TkDev']]],
  ['cmdbuf_5flen',['cmdbuf_len',['../structTkDev.html#a23750a0f857d6089fd998bfb60b42b98',1,'TkDev']]],
  ['cmdproc',['cmdproc',['../structtclMatrixXtnsnDescr.html#ac783734e4bd00b6abd73e1ff549b098d',1,'tclMatrixXtnsnDescr']]],
  ['cmds',['Cmds',['../tclAPI_8c.html#afffd7394c52d36f514b32e59ffb3e14c',1,'tclAPI.c']]],
  ['cmdtable',['cmdTable',['../tclAPI_8c.html#afe46d728dc7638d78e6a6b199b02848a',1,'tclAPI.c']]],
  ['cmdtable_5finitted',['cmdTable_initted',['../tclAPI_8c.html#a52ac14dc5aeacc898515ad58d0182c1b',1,'tclAPI.c']]],
  ['coeffs',['coeffs',['../structsquare.html#ae73bb6980efb27287ddf0f84b610b5d4',1,'square']]],
  ['colbox',['colbox',['../structPLStrip.html#a3bf05498eb14d3500b5847adcdc7c708',1,'PLStrip']]],
  ['collab',['collab',['../structPLStrip.html#a894dbc23d06f4ce3309994bc3224905c',1,'PLStrip']]],
  ['colline',['colline',['../structPLStrip.html#a43ac7953a16fc0f2e0ea2b1108256ada',1,'PLStrip']]],
  ['color',['color',['../structTkwDisplay.html#a72bf92a255cc92a519ae3b425b574a42',1,'TkwDisplay::color()'],['../structPLStream.html#a52d57f1786f9f7f58de8eb4dd7eb331c',1,'PLStream::color()'],['../structXwDisplay.html#a798c2fcc03531d090bf8633c60f07db2',1,'XwDisplay::color()'],['../ps_8c.html#a0fd02fb9277ffcb35a75066ffe95e8c7',1,'color():&#160;ps.c'],['../psttf_8cc.html#a0fd02fb9277ffcb35a75066ffe95e8c7',1,'color():&#160;psttf.cc']]],
  ['colorset',['colorset',['../structPLStream.html#adce35c7a87b6176fdb78008be0ea1ba3',1,'PLStream']]],
  ['colorstotal',['colorsTotal',['../structcdImageStruct.html#aa22fa3418f52a38c913c847346a0177f',1,'cdImageStruct']]],
  ['command',['command',['../tkMain_8c.html#a59f3f96d8bcfba6631bce1a4d1594229',1,'tkMain.c']]],
  ['completeflag',['completeFlag',['../structMemoryMapHeader.html#a108f6040fa34b7daa525ceccb8268ab9',1,'MemoryMapHeader']]],
  ['configspecs',['configSpecs',['../plframe_8c.html#a50fbe3ad7540f18279e7ba7a04edc018',1,'configSpecs():&#160;plframe.c'],['../plplotter_8c.html#a50fbe3ad7540f18279e7ba7a04edc018',1,'configSpecs():&#160;plplotter.c']]],
  ['construct_5ftype',['construct_type',['../classoctave__swig__type.html#ae653f715acb6ad400d26fdfdd36b018d',1,'octave_swig_type']]],
  ['constructor',['constructor',['../structswig__lua__class.html#aac6eb9dc9a5e0b5f2c9d31a97ce0282e',1,'swig_lua_class::constructor()'],['../structswig__octave__class.html#ad71852a41875e4faacd28de4811527b5',1,'swig_octave_class::constructor()']]],
  ['constructor_5fdoc',['constructor_doc',['../structswig__octave__class.html#af194d74802187d59e89663f93e24ddf9',1,'swig_octave_class']]],
  ['cont3d',['cont3d',['../plcont_8c.html#a5218bca39409270f30ba0feaec16166b',1,'plcont.c']]],
  ['continue_5fdraw',['continue_draw',['../structPlFrame.html#a31fbd0e66166b45175a680603076c440',1,'PlFrame::continue_draw()'],['../structPlPlotter.html#a6c349e6f3746e95efa08bdce7a2281ce',1,'PlPlotter::continue_draw()']]],
  ['contlabel_5factive',['contlabel_active',['../plcont_8c.html#a2f9f895011345cf76b65001e05c6427d',1,'plcont.c']]],
  ['contlabel_5foffset',['contlabel_offset',['../plcont_8c.html#a281225221bae473568c36f716bb88b97',1,'plcont.c']]],
  ['contlabel_5fsize',['contlabel_size',['../plcont_8c.html#a0c873f5f9cfa29944048a3ffbdf58236',1,'plcont.c']]],
  ['contlabel_5fspace',['contlabel_space',['../plcont_8c.html#a6e1956a0f29bb3fba522984a07bf1195',1,'plcont.c']]],
  ['converter',['converter',['../structswig__cast__info.html#aa630fddfbb1bf9c97a03f9479ba32f76',1,'swig_cast_info']]],
  ['coordinate_5ftransform',['coordinate_transform',['../structPLStream.html#aefab56b2f518b4e5bd4ea28b99312c4f',1,'PLStream']]],
  ['coordinate_5ftransform_5fdata',['coordinate_transform_data',['../structPLStream.html#afafb813a77b59c40efe0a1fbea1ce9e1',1,'PLStream']]],
  ['count_5fgedouble',['count_gedouble',['../bhunt__search__test_8c.html#a935d46367decec1b6908008d3a5ec974',1,'bhunt_search_test.c']]],
  ['cp',['cp',['../structhashtable.html#a79b1ec4a1dfb3f5f2952512fb4c9d127',1,'hashtable']]],
  ['csa_5fverbose',['csa_verbose',['../csa_8c.html#a66793e768e8b88c8b5a8fee75a3f911f',1,'csa_verbose():&#160;csa.c'],['../csa_8h.html#a66793e768e8b88c8b5a8fee75a3f911f',1,'csa_verbose():&#160;csa.c']]],
  ['csa_5fversion',['csa_version',['../csa_8h.html#ad3aa9b163b4d5948d49164dbc3fcfb3d',1,'csa_version():&#160;version.h'],['../csa_2version_8h.html#ad3aa9b163b4d5948d49164dbc3fcfb3d',1,'csa_version():&#160;version.h']]],
  ['csave',['csave',['../plr_8c.html#aa407bbe25b0aeeb0ad569c8f4d0072c9',1,'plr.c']]],
  ['ctmp',['ctmp',['../plot3d_8c.html#ade18f1ec445846f0d097d490b921b72e',1,'plot3d.c']]],
  ['cur_5fpos',['cur_pos',['../structPSDev.html#a9d160ccbea66d3500fa163ffc60f801b',1,'PSDev']]],
  ['curcmap',['curcmap',['../structPLStream.html#a1cf50edb6a4244934c99af266c9e5605',1,'PLStream']]],
  ['curcolor',['curcolor',['../structTkwDev.html#a5b11b525cfb716a3e504b00d51ae5910',1,'TkwDev::curcolor()'],['../structPLStream.html#a7ecc48aa20f228cb6ce457eb14bcb055',1,'PLStream::curcolor()'],['../structXwDev.html#ab836fa74d9e31e4d322ebe011ada82db',1,'XwDev::curcolor()']]],
  ['curel',['curel',['../structPLStream.html#a51aa7168acf3743f95cd61cc25e32764',1,'PLStream']]],
  ['curelemlist',['curelemlist',['../structcdImageStruct.html#a38779dd198beb9e4376053b2266d7b89',1,'cdImageStruct']]],
  ['current',['current',['../structDIR.html#a8860b81e358d3665894e31b6bd3aa78f',1,'DIR']]],
  ['currentfontscale',['currentFontScale',['../classQtPLDriver.html#aa6282d9a1ab699e0349de0e602c68959',1,'QtPLDriver']]],
  ['currentfontsize',['currentFontSize',['../classQtPLDriver.html#abd3137c592446828cf06daf8bcc138c9',1,'QtPLDriver']]],
  ['currentplot',['currentPlot',['../aqt_8c.html#a13120bcd40710b8f0722969e3b5e0fa0',1,'aqt.c']]],
  ['currlev',['currlev',['../plcont_8c.html#a96150f9d742a310a606a9f5ad303c84d',1,'plcont.c']]],
  ['currline',['currline',['../plcont_8c.html#a0f841e3b1f0da1b8ebd05659dba9a346',1,'plcont.c']]],
  ['currx',['currx',['../structPLStream.html#af7987521f0e181a4e6b409c0a8e7a112',1,'PLStream']]],
  ['curry',['curry',['../structPLStream.html#a21dab6028add62839da70a7f1d59e350',1,'PLStream']]],
  ['cursor',['cursor',['../structPlFrame.html#a8a9aaf70e61e704e6dd1504002bdd804',1,'PlFrame::cursor()'],['../structPlPlotter.html#afd0a92118904086efeac67b04263250d',1,'PlPlotter::cursor()']]],
  ['cursub',['cursub',['../structPLStream.html#afa88c5619f1949843d31b00fdfc01ee1',1,'PLStream']]],
  ['cxx',['cxx',['../structPLStream.html#a82bae71839d89e15fcba93e7e4c61396',1,'PLStream']]],
  ['cxy',['cxy',['../structPLStream.html#ad4e738abac5a871bdaed7b6a4f35ab32',1,'PLStream']]],
  ['cyx',['cyx',['../structPLStream.html#ac2b4b92112494cf3f688df8454b9d407',1,'PLStream']]],
  ['cyy',['cyy',['../structPLStream.html#a77c7b2ab5ce1aedc6ed7c42a2ccd5fd8',1,'PLStream']]],
  ['cyz',['cyz',['../structPLStream.html#a451b8d8197b4b3c0463d31850e289141',1,'PLStream']]],
  ['czx',['czx',['../structPLStream.html#a2938c215c56d483e30978a3088b472a3',1,'PLStream']]],
  ['czy',['czy',['../structPLStream.html#a93b4567d7a2eb78eed5c40679a67d013',1,'PLStream']]],
  ['czz',['czz',['../structPLStream.html#a894c2d246e4ee8436390975f2d28d16e',1,'PLStream']]]
];
